﻿using System;
using System.Collections.Generic;

using System.Drawing;
using Infragistics;
using MonoTouch.Foundation;
using MonoTouch.ObjCRuntime;
using MonoTouch.UIKit;

namespace SideMenuBlog_CS
{
	public class GridDataHelper : IGGridViewDataSourceHelper
	{
		public override string TitleForHeaderInColumn (IGGridView gridView, int column)
		{
			return "# of Items";
		}
	}

	public partial class SideMenuBlog_CSViewController : UIViewController, IIGGridViewDelegate
	{
		IGSideMenuView _sideMenuView;
		IGGridView _gridMenu;
		GridDataHelper _gridDataHelper;
		IGGridViewDarkTheme _theme;
		IGLabel _titleLabel;
		IGChartView _chartView;
		IGCategorySeriesDataSourceHelper _chartDataHelper;
		IGBarSeries _series;

		List<NSObject> _data = new List<NSObject>();
		int _amountOfData = 10;

		static bool UserInterfaceIdiomIsPhone {
			get { return UIDevice.CurrentDevice.UserInterfaceIdiom == UIUserInterfaceIdiom.Phone; }
		}

		public SideMenuBlog_CSViewController (IntPtr handle) : base (handle) {}

		public override void ViewDidLoad ()
		{
			base.ViewDidLoad ();

			_sideMenuView = new IGSideMenuView ();
			_sideMenuView.Frame = this.View.Bounds;
			_sideMenuView.AutoresizingMask = UIViewAutoresizing.FlexibleHeight | UIViewAutoresizing.FlexibleWidth;
			this.View.Add (_sideMenuView);

			InitializeTitle ();
			InitializeChart ();
			InitializeMenu ();
		}

		private void InitializeTitle()
		{
			_titleLabel = new IGLabel ();
			_titleLabel.Frame = new RectangleF (0, 0, _sideMenuView.ContentView.Bounds.Width, 50);
			_titleLabel.AutoresizingMask = UIViewAutoresizing.FlexibleWidth | UIViewAutoresizing.FlexibleBottomMargin;
			_sideMenuView.ContentView.Add(_titleLabel);

			_titleLabel.HorizontalTextAlignment = IGTextAlignment.IGTextAlignmentCenter;
			_titleLabel.BackgroundColor = UIColor.Black;
			_titleLabel.TextColor = UIColor.White;
			_titleLabel.Font = UIFont.FromName("Helvetica-Bold", 16);
			_titleLabel.Text = "Widget Item Summary";
		}

		private void InitializeChart()
		{
			_chartView = new IGChartView ();
			_chartView.Frame = new RectangleF (0, 50, _sideMenuView.ContentView.Bounds.Width, _sideMenuView.ContentView.Bounds.Height - 50);
			_chartView.AutoresizingMask = UIViewAutoresizing.FlexibleWidth | UIViewAutoresizing.FlexibleHeight | UIViewAutoresizing.FlexibleTopMargin;
			_chartView.Theme = IGChartDefaultThemes.IGThemeDark();
			_sideMenuView.ContentView.Add(_chartView);

			GenerateData(_amountOfData);
			_chartDataHelper = new IGCategorySeriesDataSourceHelper (_data.ToArray ());
			_series = (IGBarSeries)_chartView.AddSeries (new Class ("IGBarSeries"), "series", _chartDataHelper, "xAxis", "yAxis");
		}

		private void GenerateData(int count)
		{
			_data.Clear ();

			Random random = new Random (count * DateTime.Now.Millisecond);
			for (int i = 0; i < count; ++i)
			{
				_data.Add (new NSNumber (random.Next (40) + 10));
			}
		}

		private void InitializeMenu()
		{
			_gridDataHelper = new GridDataHelper ();
			_gridDataHelper.Data = new NSObject[] { (NSString)"10", (NSString)"50", (NSString)"100", (NSString)"200" };

			float gridWidth = UserInterfaceIdiomIsPhone ? 125 : 250;
			_gridMenu = new IGGridView (new RectangleF (0, 0, gridWidth, 1), IGGridViewStyle.IGGridViewStyleDefault);
			_gridMenu.SelectionType = IGGridViewSelectionType.IGGridViewSelectionTypeCell;
			_gridMenu.EmptyRows = false;
			_gridMenu.RowHeight = 45;
			_gridMenu.Theme = _theme = new IGGridViewDarkTheme ();
			_gridMenu.BackgroundColor = UIColor.FromWhiteAlpha (0.15f, 1.0f);
			_gridMenu.DataSource = _gridDataHelper;
			_gridMenu.WeakDelegate = this;
			_sideMenuView.RightMenuView = _gridMenu;
		}

		[Export ("gridView:didSelectCellAtPath:")]
		public void DidSelectCell (global::Infragistics.IGGridView gridView, global::Infragistics.IGCellPath path)
		{
			IGGridViewCell cell = (IGGridViewCell)gridView.ResolveCellForPath (path);
			_amountOfData = Int32.Parse (cell.TextLabel.Text);
			this.PerformSelector (new Selector ("ProcessMenuSelection"), null, 0.75f);
		}

		[Export ("ProcessMenuSelection")]
		private void ProcessMenuSelection()
		{
			_sideMenuView.CloseSideMenu ();
			_gridMenu.DeselectAll ();

			GenerateData (_amountOfData);
			_chartDataHelper.Values = _data.ToArray ();
			_series.DataSource = _chartDataHelper;
		}

		public override void DidReceiveMemoryWarning ()
		{
			base.DidReceiveMemoryWarning ();
		}

		public override bool PrefersStatusBarHidden ()
		{
			return true;
		}
	}
}

